@@ -2,8 +2,6 @@
 #
 # This file is part of Pod-Markdown
 #
-# This software is copyright (c) 2009-2011 by Marcel Gruenauer.
-#
 # This software is copyright (c) 2011 by Randy Stauner.
 #
 # This is free software; you can redistribute it and/or modify it under
@@ -14,11 +12,11 @@ use strict;
 use warnings;
 
 package Pod::Markdown;
-# git description: v3.002-4-gfce44d9
+# git description: v3.003-3-g01e32cf
 
 our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Convert POD to Markdown
-$Pod::Markdown::VERSION = '3.003';
+$Pod::Markdown::VERSION = '3.004';
 use Pod::Simple 3.27 (); # detected_encoding and keep_encoding bug fix
 use parent qw(Pod::Simple::Methody);
 use Encode ();
@@ -493,6 +491,18 @@ sub _encode_or_escape_entities {
   return $_;
 }
 
+# From Markdown.pl version 1.0.1 line 1172 (_DoAutoLinks).
+my $EMAIL_MARKER = qr{
+#   <                  # Opening token is in parent regexp.
+        (?:mailto:)?
+    (
+      [-.\w]+
+      \@
+      [-a-z0-9]+(\.[-a-z0-9]+)*\.[a-z]+
+    )
+    >
+}x;
+
 # Process any escapes we put in the text earlier,
 # now that the text is complete (end of a block).
 sub _process_escapes {
@@ -520,7 +530,8 @@ sub _process_escapes {
 
   if( $stash->{encode_lt} ){
     # Encode < if succeeded by chars that look like an html tag.
-    s,$_escape{lt_re}((?:[a-z/?\$!])?),
+    # Leave email addresses (<foo@bar.com>) for Markdown to process.
+    s,$_escape{lt_re}((?=$EMAIL_MARKER)|(?:[a-z/?\$!])?),
       $1 ? '<'.$2 : $2 ?  '&lt;'.$2 : '<',egos;
   }
 
@@ -1154,8 +1165,9 @@ Pod::Markdown - Convert POD to Markdown
 
 =head1 VERSION
 
-version 3.003
+version 3.004
 
+my ($pod_string);
 =head1 SYNOPSIS
 
   # Pod::Simple API is supported.
@@ -1452,8 +1464,6 @@ end_.+
 start_.+
 encode_entities
 
-=for test_synopsis my ($pod_string);
-
 =head1 SEE ALSO
 
 =over 4
@@ -1590,8 +1600,6 @@ Yasutaka ATARASHI <yakex@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009-2011 by Marcel Gruenauer.
-
 This software is copyright (c) 2011 by Randy Stauner.
 
 This is free software; you can redistribute it and/or modify it under
